<?php
/**
 * Banner Two Widget
 */

namespace Elementor;
class Falar_Banner_Two extends Widget_Base {

	public function get_name() {
        return 'Falar_Banner_Two';
    }

	public function get_title() {
        return __( 'Banner Two', 'falar-toolkit' );
    }

	public function get_icon() {
        return 'eicon-gallery-group';
    }

	public function get_categories() {
        return [ 'falar-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Falar_Banner_Two_Area',
			[
				'label' => __( 'Banner Controls', 'falar-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'title',
            [
                'label'       => __( 'Title', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('Falar - The best place to invest in your knowledge', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content',
            [
                'label'       => __( 'Content', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('Welcome to our university is website! Use the search bar below to explore our diverse range of programs.', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_text',
            [
                'label'   => __( 'Button Text', 'falar-toolkit' ),
                'type'    => Controls_Manager::TEXT,
                'default' => __('View Report', 'falar-toolkit'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'link_type',
            [
                'label' 		=> esc_html__( 'Button Link Type', 'falar-toolkit' ),
                'type' 			=> Controls_Manager::SELECT,
                'label_block' 	=> true,
                'options' => [
                    '1'  	=> esc_html__( 'Link To Page', 'falar-toolkit' ),
                    '2' 	=> esc_html__( 'External Link', 'falar-toolkit' ),
                ],
            ]
        );

        $this->add_control(
            'link_to_page',
            [
                'label' 		=> esc_html__( 'Button Link Page', 'falar-toolkit' ),
                'type' 			=> Controls_Manager::SELECT,
                'label_block' 	=> true,
                'options' 		=> falar_toolkit_get_page_as_list(),
                'condition' => [
                    'link_type' => '1',
                ]
            ]
        );

        $this->add_control(
            'ex_link',
            [
                'label'		=> esc_html__('Button External Link', 'falar-toolkit'),
                'type'		=> Controls_Manager:: TEXT,
                'condition' => [
                    'link_type' => '2',
                ]
            ]
        );

        $this->add_control(
            'card_image',
            [
                'label'       => __( 'Card Image', 'falar-toolkit' ),
                'type'        => Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'card_top_title',
            [
                'label'       => __( 'Card Top Title', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('Community', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'card_title',
            [
                'label'       => __( 'Card Title', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('Falar to celebrate more than 2,500 graduates at fall convocation', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'card_link',
            [
                'label'       => __( 'Card Link', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('#', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'view_link_text',
            [
                'label'       => __( 'View Link Text', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('View Details', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'big_left_text',
            [
                'label'       => __( 'View Left Text', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('Fal', 'falar-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'big_right_text',
            [
                'label'       => __( 'View Right Text', 'falar-toolkit' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __('ar', 'falar-toolkit'),
                'label_block' => true,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'bg_img',
                'label' => __( 'Background Image', 'falar-toolkit' ),
                'types' => [ 'classic' ],
                'selector' => '{{WRAPPER}} .hero-style2-warp::before',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => __( 'Style', 'falar-toolkit' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'title_color',
				[
					'label'     => __( 'Title Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style2-content h2' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'title_typography',
                    'label'    => __( 'Title Typography', 'falar-toolkit' ),
                    'selector' => '{{WRAPPER}} .hero-style2-content h2',
                ]
            );
			$this->add_control(
				'content_color',
				[
					'label'     => __( 'Content Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style2-content p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'content_typography',
                    'label'    => __( 'Content Typography', 'falar-toolkit' ),
                    'selector' => '{{WRAPPER}} .hero-style2-content p',
                ]
            );
            $this->add_control(
				'btn_color',
				[
					'label'     => __( 'Button Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .default-btn' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'btn_typography',
                    'label'    => __( 'Button Typography', 'falar-toolkit' ),
                    'selector' => '{{WRAPPER}} .default-btn',
                ]
            );
            $this->add_control(
				'btn_bg_color',
				[
					'label'     => __( 'Button Background Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .default-btn' => 'background-color: {{VALUE}}',
					],
				]
			);
            $this->add_control(
				'card_top_title_color',
				[
					'label'     => __( 'Card Top Title Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style2-warp .hero-item-box .content .title' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'card_top_title_typography',
                    'label'    => __( 'Card Top Title Typography', 'falar-toolkit' ),
                    'selector' => '{{WRAPPER}} .hero-style2-warp .hero-item-box .content .title',
                ]
            );
            $this->add_control(
				'card_title_color',
				[
					'label'     => __( 'Card Title Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style2-warp .hero-item-box .content h4 a' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'card_title_typography',
                    'label'    => __( 'Card Title Typography', 'falar-toolkit' ),
                    'selector' => '{{WRAPPER}} .hero-style2-warp .hero-item-box .content h4',
                ]
            );
            $this->add_control(
				'card_btn_color',
				[
					'label'     => __( 'Card Button Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style2-warp .hero-item-box .content .item-link' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'card_btn_typography',
                    'label'    => __( 'Card Button Typography', 'falar-toolkit' ),
                    'selector' => '{{WRAPPER}} .hero-style2-warp .hero-item-box .content .item-link',
                ]
            );
            $this->add_control(
				'card_bg_color',
				[
					'label'     => __( 'Card Background Color', 'falar-toolkit' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .hero-style2-warp .hero-item-box' => 'background-color: {{VALUE}}',
					],
				]
			);
            
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Get Button Link
        $link = '#';
        if( $settings['link_type'] == 1 ){
            $link = get_page_link( $settings['link_to_page'] );
        } else {
            $link = $settings['ex_link'];
        }

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        ?>

        <!-- Hero Style2 Warp Start -->
        <div class="hero-style2-warp">
            <div class="container-fluid">
                <div class="hero-style2-content" data-cue="slideInLeft">
                    <?php if( $settings['title']): ?>
                        <h2><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if( $settings['content']): ?>
                        <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                    <?php endif; ?>
                    <?php if( $settings['button_text']): ?>
                        <a href="<?php echo esc_url( $link ); ?>" class="default-btn">
                            <?php echo esc_html( $settings['button_text'] ); ?>
                            <i class="ti ti-arrow-narrow-right"></i>
                        </a>
                    <?php endif; ?>
                </div>
                <div class="hero-item-box" data-cue="slideInDown">
                    <?php if( $settings['card_image']['url'] != '' ): ?>
                        <div class="image">
                            <div class="image">
                                <img src="<?php echo esc_url($settings['card_image']['url'] ) ?>" alt="image">
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="content">
                        <?php if( $settings['card_top_title']): ?>
                            <span class="title"><?php echo wp_kses_post( $settings['card_top_title'] ); ?></span>
                        <?php endif; ?>
                        <?php if( $settings['card_title']): ?>
                            <h4>
                                <a href="<?php echo wp_kses_post( $settings['card_link'] ); ?>"><?php echo wp_kses_post( $settings['card_title'] ); ?></a>
                            </h4>
                        <?php endif; ?>
                        <?php if( $settings['card_link']): ?>
                            <a href="<?php echo wp_kses_post( $settings['card_link'] ); ?>" class="item-link">
                                <span><?php echo wp_kses_post( $settings['view_link_text'] ); ?></span>
                                <i class="ti ti-arrow-narrow-right"></i>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="big-size-text">
                    <?php if( $settings['big_left_text']): ?>
                        <span><?php echo wp_kses_post( $settings['big_left_text'] ); ?></span>
                    <?php endif; ?>
                    <?php if( $settings['big_right_text']): ?>
                        <span><?php echo wp_kses_post( $settings['big_right_text'] ); ?></span>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- Hero Style2 Warp End -->
        <?php
	}

}

Plugin::instance()->widgets_manager->register( new Falar_Banner_Two );